@@ -9,6 +9,9 @@
 #' @param plyFile An object of class 'mesh3d' and 'shape3d' with calculated normals
 #' @param outliers The percentile of Dirichlet energy density values to be excluded 
 #' defaults to top 0.1 percent
+#' @param BoundaryDiscard Logical indicating how to handle the exclusion of 
+#' boundary faces. Defaults to Leg which exlcudes faces which have a leg on the
+#' boundary
 #'
 #' @details The function requires an object created by reading in a ply file utilizing
 #' either the read.ply or the read.AVIZO.ply function, with calculated normals.
@@ -17,10 +20,13 @@
 #' have already been simplified to 10,000 faces and pre-smoothed in a 3D data
 #' editing program. 
 #'
-#' The function does not include boundary vertices in the calculation, and therefore the
-#' analyzed surface cannot be closed (i.e., it must contain a hole). The function defaults to
-#' remove the top 0.1 percent of calculated energy densities as outliers. Mesh orientation
-#' does not affect for this calculation.
+#' In the default settings, the function seeks to discard boundary faces. This can be 
+#' changed by adjusting the BoundaryDiscard argumen to 'None' which will not discard 
+#' any faces on on the boundary. Further, there are two ways of excluding boundary faces.
+#' Either if they have a leg on the boundary by setting BoundaryDiscard='Leg' or by 
+#' excluding any face which has a vertex on the boundary with BoundaryDiscard='Vertex'.
+#' The function defaults to remove the top 0.1 percent of calculated energy densities as 
+#' outliers. Mesh orientation does not affect for this calculation.
 #'
 #' @importFrom
 #' stats quantile aggregate
@@ -35,23 +41,35 @@
 
 
 
-DNE <- function(plyFile, outliers=0.1) {
-	
+DNE <- function(plyFile, outliers=0.1, BoundaryDiscard='Leg') {
+	if(BoundaryDiscard!='Leg' && BoundaryDiscard!='Vertex' && BoundaryDiscard!='None'){
+		stop("BoundaryDiscard must be set to 'Leg' 'Vertex' or 'None'. Selected 'None' if you are working with a closed surface.")
+	}
 	size <- cSize(plyFile$vb[-4,])
 	plyFile$vb <- plyFile$vb/size*100
 	
 	ply <- Equal_Vertex_Normals(plyFile) ## Correct the Vertex Normals Calculation
 	Es <- compute_energy_per_face(ply) ## Compute DNE values for each face of the surface
 	
-	
+	if(BoundaryDiscard!='None'){
 	### Extracting and removing Edge Facess
-	edges <- vcgGetEdge(plyFile)
-	temp <- subset(edges, edges$border==1)
-	EdgeEs <- sort(as.numeric(temp$facept))
+	if(BoundaryDiscard=='Leg') {
+		edges <- vcgGetEdge(plyFile)
+		temp <- subset(edges, edges$border==1)
+		EdgeEs <- sort(as.numeric(temp$facept))
+	}
+	if(BoundaryDiscard=='Vertex') {
+		edges <- vcgGetEdge(plyFile)
+		bounds <- subset(edges, edges$border==1)
+		edgeverts <- unique(c(bounds$vert1, bounds$vert2))
+		list <- vertex_to_face_list(plyFile)
+		EdgeEs <- sort(unique(unlist(list[edgeverts])))
+	}
 	
 	Boundary_Values <- Es[EdgeEs,] ## This to be Exported, values of edge faces
 	
 	Es[EdgeEs,]$Dirichlet_Energy_Densities <- 0
+	}
 	
 	### Extracting and removing outliers
 	outs <- (100-outliers)/100
@@ -76,8 +94,10 @@ DNE <- function(plyFile, outliers=0.1) {
 	Outliers[,1] <- Outliers[,1]/size*100
 	Outliers[,2] <- Outliers[,2]*size/100
 	
+	if(BoundaryDiscard!='None'){
 	Boundary_Values[,1] <- Boundary_Values[,1]/size*100
 	Boundary_Values[,2] <- Boundary_Values[,2]*size/100
+	}
 	
 	nor <- ply$vb[4,]
 	vbs <- plyFile$vb*size/100
@@ -85,9 +105,12 @@ DNE <- function(plyFile, outliers=0.1) {
 	rebuild <- rbind(vbs, nor)
 	plyFile$vb <- rebuild
 	
+	if(BoundaryDiscard=='None') {
+		Boundary_Values="No Boundary or No Boundary Discard Selected"
+	}
+	
 	Out <- list(Surface_DNE=Surface_DNE, Face_Values=CleanEs, Boundary_Values=Boundary_Values, Outliers=Outliers, "plyFile"=plyFile)
-	print("Total Surface DNE")
-	print(Surface_DNE)
+	cat("Total Surface DNE =", Surface_DNE)
 	return(Out)
 	
 }
\ No newline at end of file
